@@ -497,9 +497,10 @@ wrap_table_get_num_fitting (int available,
 {
 	int num;
 
-  	g_return_val_if_fail (available >= 0, 0);
   	g_return_val_if_fail (max_child_size > 0, 0);
   	g_return_val_if_fail (spacing >= 0, 0);
+
+	available = MAX (available, 0);
 	
 	num = (available + spacing) / (max_child_size + spacing);
 	num = MAX (num, 1);
@@ -523,7 +524,8 @@ wrap_table_layout (EelWrapTable *wrap_table)
 	pos.x = content_bounds.x0;
 	pos.y = content_bounds.y0;
 
-	num_cols = wrap_table_get_num_fitting (GTK_WIDGET (wrap_table)->allocation.width,
+	num_cols = wrap_table_get_num_fitting (GTK_WIDGET (wrap_table)->allocation.width -
+					       GTK_CONTAINER (wrap_table)->border_width * 2,
 					       wrap_table->details->x_spacing,
 					       max_child_dimensions.width);
 	if (num_cols != wrap_table->details->cols) {
@@ -674,7 +676,8 @@ wrap_table_get_content_dimensions (const EelWrapTable *wrap_table)
 		max_child_dimensions.width = MAX (max_child_dimensions.width, 1);
 		max_child_dimensions.height = MAX (max_child_dimensions.height, 1);
 
-		num_cols = wrap_table_get_num_fitting (dimensions.width,
+		num_cols = wrap_table_get_num_fitting (dimensions.width -
+						       GTK_CONTAINER (wrap_table)->border_width * 2,
 						       wrap_table->details->x_spacing,
 						       max_child_dimensions.width);
 		num_rows = num_children / num_cols;
